<?php

if (!defined('_CAN_LOAD_FILES_'))
	exit;

class Awesomeslider extends Module
{
	/** @var max image size */
	protected $maxImageSize = 800000;

	public function __construct()
	{
		$this->name = 'awesomeslider';
		$this->tab = 'DapurPixel';
		$this->version = '1.0';
		
		parent::__construct();

		$this->displayName = $this->l('Homepage Awesome Slider');
		$this->description = $this->l('A picture slideshow for your homepage');
	}

	public function install()
	{
		if (!parent::install())
			return false;
		return $this->registerHook('home');
	}

	function putContent($xml_data, $key, $field, $forbidden, $section)
	{
		foreach ($forbidden AS $line)
			if ($key == $line)
				return 0;
		if (!preg_match('/^'.$section.'_/i', $key))
			return 0;
		$key = preg_replace('/^'.$section.'_/i', '', $key);
		$field = htmlspecialchars($field);
		if (!$field)
			return 0;
		return ("\n".'		<'.$key.'>'.$field.'</'.$key.'>');
	}

	function getContent()
	{
		/* display the module name */
		$this->_html = '<h2>'.$this->displayName.'</h2>';
		$errors = '';

		/* update the editorial xml */
		if (isset($_POST['submitUpdate']))
		{
			// Forbidden key
			$forbidden = array('submitUpdate');
			
			foreach ($_POST AS $key => $value)
				if (!Validate::isString($_POST[$key]))
				{
					$this->_html .= $this->displayError($this->l('Invalid html field, javascript is forbidden'));
					$this->_displayForm();
					return $this->_html;
				}

			// Generate new XML data
			$newXml = '<?xml version=\'1.0\' encoding=\'utf-8\' ?>'."\n";
			$newXml .= '<awesomeslider>'."\n";
			$newXml .= '	<header>';
			// Making header data
			foreach ($_POST AS $key => $field)
				if ($line = $this->putContent($newXml, $key, $field, $forbidden, 'header'))
					$newXml .= $line;
			$newXml .= "\n".'	</header>'."\n";
			$newXml .= '	<body>';
			// Making body data
			foreach ($_POST AS $key => $field)
				if ($line = $this->putContent($newXml, $key, $field, $forbidden, 'body'))
					$newXml .= $line;
			$newXml .= "\n".'	</body>'."\n";
			$newXml .= '</awesomeslider>'."\n";
			
			
			/* write it into the editorial xml file */
			if ($fd = @fopen(dirname(__FILE__).'/awesomeslider.xml', 'w'))
			{
				if (!@fwrite($fd, $newXml))
					$errors .= $this->displayError($this->l('Unable to write to the editor file.'));
				if (!@fclose($fd))
					$errors .= $this->displayError($this->l('Can\'t close the editor file.'));
			}
			else
				$errors .= $this->displayError($this->l('Unable to update the editor file.<br />Please check the editor file\'s writing permissions.'));
			
			$angka = 1;
			while ($angka <= 5) {
				/* upload the image */
				if (isset($_FILES['body_homepage_logo'.$angka]) AND isset($_FILES['body_homepage_logo'.$angka]['tmp_name']) AND !empty($_FILES['body_homepage_logo'.$angka]['tmp_name']))
				{
					Configuration::set('PS_IMAGE_GENERATION_METHOD', 1);
					if ($error = checkImage($_FILES['body_homepage_logo'.$angka], $this->maxImageSize))
						$errors .= $error;
					elseif (!$tmpName = tempnam(_PS_TMP_IMG_DIR_, 'PS') OR !move_uploaded_file($_FILES['body_homepage_logo'.$angka]['tmp_name'], $tmpName))
						return false;
					elseif (!imageResize($tmpName, dirname(__FILE__).'/homepage_logo'.$angka.'.jpg'))
						$errors .= $this->displayError($this->l('An error occurred during the image upload.'));
					unlink($tmpName);
				}
				$angka++;
			}
			
			$this->_html .= $errors == '' ? $this->displayConfirmation('Settings updated successfully') : $errors;
		}

		/* display the editorial's form */
		$this->_displayForm();
	
		return $this->_html;
	}

	private function _displayForm()
	{
		global $cookie;
		/* Languages preliminaries */
		$defaultLanguage = intval(Configuration::get('PS_LANG_DEFAULT'));
		$languages = Language::getLanguages();
		$iso = Language::getIsoById(intval($cookie->id_lang));
		$divLangName = 'title¤subheading¤cpara¤logo_subheading';

		/* xml loading */
		$xml = false;
		if (file_exists(dirname(__FILE__).'/awesomeslider.xml'))
				if (!$xml = simplexml_load_file(dirname(__FILE__).'/awesomeslider.xml'))
					$this->_html .= $this->displayError($this->l('Your editor file is empty.'));

		$this->_html .= '
		<script type="text/javascript" src="'.__PS_BASE_URI__.'js/tinymce/jscripts/tiny_mce/jquery.tinymce.js"></script>
		<script type="text/javascript">
		function tinyMCEInit(element)
		{
			$().ready(function() {
				$(element).tinymce({
					// Location of TinyMCE script
					script_url : \''.__PS_BASE_URI__.'js/tinymce/jscripts/tiny_mce/tiny_mce.js\',
					// General options
					theme : "advanced",
					plugins : "safari,pagebreak,style,layer,table,advimage,advlink,inlinepopups,media,searchreplace,contextmenu,paste,directionality,fullscreen",
					// Theme options
					theme_advanced_buttons1 : "newdocument,|,bold,italic,underline,strikethrough,|,justifyleft,justifycenter,justifyright,justifyfull,styleselect,formatselect,fontselect,fontsizeselect",
					theme_advanced_buttons2 : "cut,copy,paste,pastetext,pasteword,|,search,replace,|,bullist,numlist,|,outdent,indent,blockquote,|,undo,redo,|,link,unlink,anchor,image,cleanup,help,code,,|,forecolor,backcolor",
					theme_advanced_buttons3 : "tablecontrols,|,hr,removeformat,visualaid,|,sub,sup,|,charmap,media,|,ltr,rtl,|,fullscreen",
					theme_advanced_buttons4 : "insertlayer,moveforward,movebackward,absolute,|,styleprops,|,cite,abbr,acronym,del,ins,attribs,|,pagebreak",
					theme_advanced_toolbar_location : "top",
					theme_advanced_toolbar_align : "left",
					theme_advanced_statusbar_location : "bottom",
					theme_advanced_resizing : false,
					content_css : "'.__PS_BASE_URI__.'themes/'._THEME_NAME_.'/css/global.css",
					document_base_url : "'.__PS_BASE_URI__.'",					
					width: "582",
					height: "auto",
					font_size_style_values : "8pt, 10pt, 12pt, 14pt, 18pt, 24pt, 36pt",
					elements : "nourlconvert",
					convert_urls : false,
					language : "'.(file_exists(_PS_ROOT_DIR_.'/js/tinymce/jscripts/tiny_mce/langs/'.$iso.'.js') ? $iso : 'en').'"
				});
			});
		}
		tinyMCEInit(\'textarea.rte\');
		</script>
		<script type="text/javascript">id_language = Number('.$defaultLanguage.');</script>
		<script type="text/javascript" src="'.$this->_path.'scripts/addinput.js"></script>
		<form method="post" action="'.$_SERVER['REQUEST_URI'].'" enctype="multipart/form-data">
			<fieldset style="width: 900px;">
				<legend><img src="'.$this->_path.'logo.gif" alt="" title="" /> '.$this->displayName.'</legend>
				<div class="addremoveslider" style="float:left; width:100%; margin-bottom:10px;">
				<a class="add" href="#"><img src="'.$this->_path.'/images/add.png" /></a>
				<a class="remove" href="#"><img src="'.$this->_path.'/images/remove.png" /></a>
				<a class="reset" href="#"><img src="'.$this->_path.'/images/reset.png" /></a>
				</div>
				
				<div id="formslider">
				';
				$loopelement = 1; 
				while ($loopelement <= 2) 
				{
				$link = 'home_logo_link'.$loopelement;
				$this->_html .= '
					<div class="wrapper_element">
					<label>'.$this->l('Picture '.$loopelement).' </label>
					<div class="margin-form">
						<img src="'.$this->_path.'homepage_logo'.$loopelement.'.jpg" alt="" title="" style="" /><br />
						<input type="file" class="images" name="body_homepage_logo'.$loopelement.'" />
						<p style="clear: both">'.$this->l('Will appear next to the Introductory Text above').'</p>
					</div>
					<label>'.$this->l('Picture \'s '.$loopelement.' Link').'</label>
					<div class="margin-form">
						<input type="text" class="links" name="body_home_logo_link'.$loopelement.'" size="64" value="'.($xml ? stripslashes(htmlspecialchars($xml->body->$link)) : '').'" />
						<p style="clear: both">'.$this->l('Link used on the 2nd logo').'</p>
					</div>
					</div>';
					$loopelement++;
					}
					
					
					
				$this->_html .= '
				</div>
				<div class="clear pspace"></div>
				<div class="margin-form clear"><input type="submit" name="submitUpdate" value="'.$this->l('Update the editor').'" class="button" /></div>
			</fieldset>
		</form>
				';
				
				
	}

	function hookHome($params)
	{
		if (file_exists('modules/awesomeslider/awesomeslider.xml'))
		{
			if ($xml = simplexml_load_file('modules/awesomeslider/awesomeslider.xml'))
			{
				global $cookie, $smarty;
				$smarty->assign(array(
					'xml' => $xml,
					'homepage_logo1' => file_exists('modules/awesomeslider/homepage_logo1.jpg'),
					'homepage_logo2' => file_exists('modules/awesomeslider/homepage_logo2.jpg'),
					'homepage_logo3' => file_exists('modules/awesomeslider/homepage_logo3.jpg'),
					'homepage_logo4' => file_exists('modules/awesomeslider/homepage_logo4.jpg'),
					'homepage_logo5' => file_exists('modules/awesomeslider/homepage_logo5.jpg'),
					'total_elements' => 3,
					'logo_subheading' => 'logo_subheading_'.$cookie->id_lang,
					'title' => 'title_'.$cookie->id_lang,
					'subheading' => 'subheading_'.$cookie->id_lang,
					'paragraph' => 'paragraph_'.$cookie->id_lang,
					'this_path' => $this->_path
				));
				return $this->display(__FILE__, 'awesomeslider.tpl');
			}
		}
		return false;
	}

}
